@@ -10,10 +10,12 @@ __all__ = [
     "AnyParameter",
     "IntParameter",
     "FloatParameter",
+    "StrParameter",
     "BoolParameter",
     "ListParameter",
     "IntListParameter",
     "FloatListParameter",
+    "StrListParameter",
     "OptionsParameter",
 ]
 
@@ -92,6 +94,7 @@ class FloatParameter(Parameter):
 class StrParameter(Parameter):
 
     def __init__(self, allow_none: bool = False) -> None:
+        super().__init__()
         self._allow_none = allow_none
 
     def __repr__(self) -> str:
@@ -109,21 +112,71 @@ class BoolParameter(Parameter):
 
 
 class ListParameter(Parameter):
+
+    def __init__(self, n: Optional[int] = None):
+        super().__init__()
+        self._n = n
+
+    def __repr__(self) -> str:
+        return f"{self.__class__.__name__}(n={self._n!r})"
     
     def validate(self, instance, value):
-        return validators.validate_anylist(value)
+        c_val = validators.validate_anylist(value)
+        if self._n is not None:
+            if len(c_val) != self._n:
+                raise ValueError(f"Expected {self._n} values, but there are {len(c_val)} values in {value}")
+        return c_val
 
 
 class IntListParameter(Parameter):
 
+    def __init__(self, n: Optional[int] = None):
+        super().__init__()
+        self._n = n
+
+    def __repr__(self) -> str:
+        return f"{self.__class__.__name__}(n={self._n!r})"
+
     def validate(self, instance, value):
-        return validators.validate_intlist(value)
+        c_val = validators.validate_intlist(value)
+        if self._n is not None:
+            if len(c_val) != self._n:
+                raise ValueError(f"Expected {self._n} values, but there are {len(c_val)} values in {value}")
+        return c_val
 
 
 class FloatListParameter(Parameter):
 
+    def __init__(self, n: Optional[int] = None):
+        super().__init__()
+        self._n = n
+
+    def __repr__(self) -> str:
+        return f"{self.__class__.__name__}(n={self._n!r})"
+
     def validate(self, instance, value):
-        return validators.validate_floatlist(value)
+        c_val = validators.validate_floatlist(value)
+        if self._n is not None:
+            if len(c_val) != self._n:
+                raise ValueError(f"Expected {self._n} values, but there are {len(c_val)} values in {value}")
+        return c_val
+
+
+class StrListParameter(Parameter):
+
+    def __init__(self, n: Optional[int] = None):
+        super().__init__()
+        self._n = n
+
+    def __repr__(self) -> str:
+        return f"{self.__class__.__name__}(n={self._n!r})"
+
+    def validate(self, instance, value):
+        c_val = validators.validate_strlist(value)
+        if self._n is not None:
+            if len(c_val) != self._n:
+                raise ValueError(f"Expected {self._n} values, but there are {len(c_val)} values in {value}")
+        return c_val
 
 
 class OptionsParameter(Parameter):
